﻿Type=Class
Version=3.96
ModulesStructureVersion=1
B4J=true
@EndOfDesignText@
'Class module
Sub Class_Globals
	Private ws As WebSocket 'ignore
	' will hold our page information
	Public page As ABMPage
	' page theme
	Private theme As ABMTheme
	' to access the constants
	Private ABM As ABMaterial 'ignore	
	' name of the page, must be the same as the class name (case sensitive!)
	Public Name As String = "CompCardPage"
	' name of the app, same as in ABMApplication
	Public AppName As String = "demo"
	
	' your own variables
	Dim myToastId As Int
End Sub

'Initializes the object. You can add parameters to this method if needed.
Public Sub Initialize
	' build the local structure IMPORTANT!
	BuildPage
End Sub

Private Sub WebSocket_Connected (WebSocket1 As WebSocket)
	Log("Connected")
	ws = WebSocket1	
	If ABMShared.NeedsAuthorization Then
		If ws.Session.GetAttribute2("IsAuthorized", "") = "" Then
			ABMShared.NavigateToPage(ws, "../")
			Return
		End If
	End If
	' connect our page with the websocket	
	page.SetWebSocket(ws)
	' Prepare the page IMPORTANT!
	page.Prepare	
End Sub

Private Sub WebSocket_Disconnected
	Log("Disconnected")
End Sub

Sub Page_ParseEvent(Params As Map) 
	Dim eventName As String = Params.Get("eventname")
	Dim eventParams() As String = Regex.Split(",",Params.Get("eventparams"))
	If SubExists(Me, eventName) Then
		Params.Remove("eventname")
		Params.Remove("eventparams")
		Select Case Params.Size
			Case 0
				CallSub(Me, eventName)
			Case 1
				CallSub2(Me, eventName, Params.Get(eventParams(0)))					
			Case 2
				If Params.get(eventParams(0)) = "abmistable" Then
					Dim PassedTables As List = ABM.ProcessTablesFromTargetName(Params.get(eventParams(1)))
					CallSub2(Me, eventName, PassedTables)
				Else
					CallSub3(Me, eventName, Params.Get(eventParams(0)), Params.Get(eventParams(1)))
				End If
			Case Else
				' cannot be called diretly, to many param
				CallSub2(Me, eventName, Params)				
		End Select
	End If
End Sub

public Sub BuildTheme()
	' start with the base theme defined in ABMShared
	theme.Initialize("pagetheme")
	theme.AddABMTheme(ABMShared.MyTheme)
	
	' add additional themes specific for this page	
	
	' card themes
	theme.AddCardTheme("basiccard")
	theme.Card("basiccard").BackColor = ABM.COLOR_BLUEGREY
	theme.Card("basiccard").TitleForeColor = ABM.COLOR_WHITE
	theme.Card("basiccard").ContentForeColor = ABM.COLOR_WHITE
	theme.Card("basiccard").ActionForeColor = ABM.COLOR_ORANGE
	
	theme.AddCardTheme("whitetitle")
	theme.Card("whitetitle").TitleForeColor = ABM.COLOR_WHITE
	
	theme.AddCardTheme("redpanel")
	theme.Card("redpanel").ContentForeColor = ABM.COLOR_WHITE
	theme.Card("redpanel").BackColor = ABM.COLOR_RED
End Sub

public Sub BuildPage()
	' initialize the theme
	BuildTheme
	
	' initialize this page using our theme
	page.InitializeWithTheme(Name, "/ws/" & AppName & "/" & Name, False, theme)
	page.ShowLoader=True
	page.PageTitle = "ABMCard"
	page.PageDescription = "The card component "	
	page.PageHTMLName = "abmaterial-card.html"
	page.PageKeywords = "ABMaterial, material design, B4X, B4J, SEO, framework, search engine optimization"
	page.PageSiteMapPriority = "0.50"
	page.PageSiteMapFrequency = ABM.SITEMAP_FREQ_MONTHLY
	
	ABMShared.BuildNavigationBar(page, "ABMCard", "../images/logo.png", "", "Controls", "ABMCard")
		
	' create the page grid
	page.AddRows(1,True, "").AddCells12(1,"")	
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,6,6,"")	
	page.AddRows(2,True, "").AddCells12(1,"")	
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,7,7,"")
	page.AddRows(2,True, "").AddCells12(1,"")		
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,7,7,"")
	page.AddRows(2,True, "").AddCells12(1,"")			
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,6,6,"")	
	page.AddRows(1,True, "").AddCells12(1,"")		
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,7,7,"")	
	page.AddRows(1,True, "").AddCells12(1,"")		
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,8,8,"")	
	page.AddRows(1,True, "").AddCells12(1,"")		
	page.AddRows(1,True, "").AddCellsOS(1,0,0,0,12,6,6,"")	
	page.AddRows(1,True, "").AddCells12(1,"")		
	page.BuildGrid 'IMPORTANT once you loaded the complete grid AND before you start adding components
	
	' add paragraph	
	page.Cell(1,1).AddComponent(ABMShared.BuildParagraph(page,"par1","Cards are a convenient means of displaying content composed of different types of objects. They’re also well-suited for presenting similar objects whose size or supported actions can vary considerably, like photos with captions of variable length.") )
	
	' add a header label
	page.Cell(1,1).AddComponent(ABMShared.BuildHeader(page,"hdr1", "Basic Card"))
	
	' basic card
	Dim card1 As ABMCard
	card1.InitializeAsCard(page, "card1", "Card Title", "I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively.", ABM.CARD_NOTSPECIFIED,"basiccard")
	card1.AddAction("BUTTON 1")
	card1.AddAction("BUTTON 2")
	page.Cell(2,1).AddComponent(card1)
		
	' add codeblock	
	Dim code As StringBuilder
	code.Initialize
	code.Append("Dim card1 As ABMCard").Append(CRLF)
	code.Append("card1.InitializeAsCard(page, ""card1"", ""Card Title"", ""I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively."", ABM.CARD_NOTSPECIFIED,""basiccard"")").Append(CRLF)
	code.Append("card1.AddAction(""BUTTON 1"")").Append(CRLF)
	code.Append("card1.AddAction(""BUTTON 2"")").Append(CRLF)
	code.Append("page.Cell(2,1).AddComponent(card1)").Append(CRLF)
	
	page.Cell(3,1).AddComponent(ABMShared.BuildCodeBlock(page, "code", code))
	
	' add a header label
	page.Cell(4,1).AddComponent(ABMShared.BuildHeader(page,"hdr2", "Image Card"))
	
	' add paragraph	
	page.Cell(4,1).AddComponent(ABMShared.BuildParagraph(page,"par2","Here is the standard card with an image thumbnail.") )
	
	' image card
	Dim card2 As ABMCard
	card2.InitializeAsCard(page, "card2", "Card Title", "I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively.", ABM.CARD_NOTSPECIFIED,"whitetitle")
	card2.Image = "../images/sample-1.jpg"
	card2.AddAction("BUTTON 1")
	page.Cell(5,1).AddComponent(card2)
	
	' add codeblock	
	Dim code2 As StringBuilder
	code2.Initialize
	code2.Append("Dim card2 As ABMCard").Append(CRLF)
	code2.Append("card2.InitializeAsCard(page, ""card2"", ""Card Title"", ""I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively."", ABM.CARD_NOTSPECIFIED,""whitetitle"")").Append(CRLF)
	code2.Append("card2.Image = ""../images/sample-1.jpg""").Append(CRLF)
	code2.Append("card2.AddAction(""BUTTON 1"")").Append(CRLF)
	code2.Append("page.Cell(5,1).AddComponent(card2)").Append(CRLF)
	
	page.Cell(6,1).AddComponent(ABMShared.BuildCodeBlock(page, "code2", code2))
	
	' add a header label
	page.Cell(7,1).AddComponent(ABMShared.BuildHeader(page,"hdr3", "Card Reveal"))
	
	' add paragraph	
	page.Cell(7,1).AddComponent(ABMShared.BuildParagraph(page,"par3","Here you can add a card that reveals more information once clicked. Just add the line .IsReveal = true.") )
	
	' image card
	Dim card3 As ABMCard
	card3.InitializeAsCard(page, "card3", "Card Title", "I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively.", ABM.CARD_NOTSPECIFIED,"")
	card3.Image = "../images/sample-2.jpg"
	card3.IsReveal = True
	card3.AddAction("BUTTON 1")
	page.Cell(8,1).AddComponent(card3)
	
	' add codeblock	
	Dim code3 As StringBuilder
	code3.Initialize
	code3.Append("Dim card3 As ABMCard").Append(CRLF)
	code3.Append("card3.InitializeAsCard(page, ""card3"", ""Card Title"", ""I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively."", ABM.CARD_NOTSPECIFIED,"""")").Append(CRLF)
	code3.Append("card3.Image = ""../images/sample-1.jpg""").Append(CRLF)
	code3.Append("card3.IsReveal = True").Append(CRLF)
	code3.Append("card2.AddAction(""BUTTON 1"")").Append(CRLF)
	code3.Append("page.Cell(8,1).AddComponent(card3)").Append(CRLF)
	
	page.Cell(9,1).AddComponent(ABMShared.BuildCodeBlock(page, "code3", code3))
	
	' add a header label
	page.Cell(10,1).AddComponent(ABMShared.BuildHeader(page,"hdr3", "Card Sizes"))
	
	' add paragraph	
	page.Cell(10,1).AddComponent(ABMShared.BuildParagraph(page,"par3","If you want to have uniformly sized cards, you can use our premade size types. Just add the size type in the Initialize method. The width is not affected by this parameter but is determined by your cell size.") )
	
	' add a sub header label
	page.Cell(10,1).AddComponent(ABMShared.BuildSubHeader(page,"hdr4", "CARD_SMALL"))
	
	' add paragraph	
	page.Cell(10,1).AddComponent(ABMShared.BuildParagraph(page,"par4","The Small Card limits the height of the card to 300px.") )
	
	' image card
	Dim card4 As ABMCard
	card4.InitializeAsCard(page, "card4", "Small", "Note: Because I have a fixed height, my text may not fit!", ABM.CARD_SMALL,"whitetitle")
	card4.Image = "../images/sample-1.jpg"
	card4.AddAction("BUTTON 1")
	card4.AddAction("BUTTON 2")
	page.Cell(11,1).AddComponent(card4)
	
	' add a sub header label
	page.Cell(12,1).AddComponent(ABMShared.BuildSubHeader(page,"hdr5", "CARD_MEDIUM"))
	
	' add paragraph	
	page.Cell(12,1).AddComponent(ABMShared.BuildParagraph(page,"par5","The Medium Card limits the height of the card to 400px.") )
	
	' image card
	Dim card5 As ABMCard
	card5.InitializeAsCard(page, "card5", "Medium", "Note: Because I have a fixed height, my text may not fit!", ABM.CARD_MEDIUM,"whitetitle")
	card5.Image = "../images/sample-1.jpg"
	card5.AddAction("BUTTON 1")
	card5.AddAction("BUTTON 2")
	page.Cell(13,1).AddComponent(card5)
	
	' add a sub header label
	page.Cell(14,1).AddComponent(ABMShared.BuildSubHeader(page,"hdr6", "CARD_LARGE"))
	
	' add paragraph	
	page.Cell(14,1).AddComponent(ABMShared.BuildParagraph(page,"par6","The Large Card limits the height of the card to 500px.") )
	
	' image card
	Dim card6 As ABMCard
	card6.InitializeAsCard(page, "card6", "Large", "Note: Because I have a fixed height, my text may not fit!", ABM.CARD_LARGE,"whitetitle")
	card6.Image = "../images/sample-1.jpg"
	card6.AddAction("BUTTON 1")
	card6.AddAction("BUTTON 2")
	page.Cell(15,1).AddComponent(card6)
	
	' add a header label
	page.Cell(16,1).AddComponent(ABMShared.BuildHeader(page,"hdr7", "Card Panel"))
	
	' add paragraph	
	page.Cell(16,1).AddComponent(ABMShared.BuildParagraph(page,"par7","For a simpler card with less markup, try using a card panel which just has padding and a shadow effect") )
	
	' image card
	Dim card7 As ABMCard
	card7.InitializeAsPanel(page, "card7", "I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively. I am similar to what is called a panel in other frameworks." ,"redpanel")
	page.Cell(17,1).AddComponent(card7)
	
	' add codeblock	
	Dim code4 As StringBuilder
	code4.Initialize
	code4.Append("Dim card4 As ABMCard").Append(CRLF)
	code4.Append("card7.InitializeAsPanel(page, ""card7"", ""I am a very simple card. I am good at containing small bits of information. I am convenient because I require little markup to use effectively. I am similar to what is called a panel in other frameworks."" ,""redpanel""))").Append(CRLF)
	code4.Append("page.Cell(17,1).AddComponent(card7)").Append(CRLF)
	
	page.Cell(18,1).AddComponent(ABMShared.BuildCodeBlock(page, "code4", code4))
	
	ABMShared.BuildFooter(page)
End Sub

' clicked on the navigation bar
Sub Page_NavigationbarClicked(Action As String, Value As String)
	page.SaveNavigationBarPosition	
	If Action = "ABMCard" Then Return
	If Action = "Contact" Then	
		myToastId = myToastId + 1
		page.ShowToast("toast" & myToastId, "toastred", "Hello to you too!", 5000)
		Return
	End If
	If Action = "LogOff" Then
		ABMShared.LogOff(page)
		Return
	End If
	ABMShared.NavigateToPage(ws, Value)
End Sub

Sub Page_SignedOffSocialNetwork(Network As String, Extra As String)
	page.ws.Session.SetAttribute("authType", "")
	page.ws.Session.SetAttribute("authName", "")
	page.ws.Session.SetAttribute("IsAuthorized", "")			
	ABMShared.NavigateToPage(page.ws, "../")
End Sub

Sub Page_Ready()
	Log("ready!")
	page.RestoreNavigationBarPosition
End Sub

Sub card1_LinkClicked(Card As String, Action As String)
	myToastId = myToastId + 1
	page.ShowToast("toast" & myToastId, "toastred", "Clicked on " & Action & "!", 5000)
End Sub

